@@ -1187,8 +1187,7 @@ game_about_callback (GSimpleAction *action,
                          "documenters", documenters,
                          "translator-credits", _("translator-credits"),
                          "logo-icon-name", "five-or-more",
-                         "website", "http://www.gnome.org/projects/gnome-games/",
-                         "website-label", _("GNOME Games web site"),
+                         "website", "https://wiki.gnome.org/Apps/Five%20or%20more",
                          NULL);
 }
 
